# Generated by Django 3.2.5 on 2021-07-24 17:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0017_auto_20210724_2306'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='assessment',
            options={'permissions': [('preview_assessment', 'Can preview assessment')]},
        ),
        migrations.AlterField(
            model_name='assessment',
            name='duration',
            field=models.FloatField(help_text='This duration will be in minutes'),
        ),
        migrations.AlterField(
            model_name='assessment',
            name='score',
            field=models.FloatField(help_text='This will auto'),
        ),
    ]
