# Generated by Django 3.2.5 on 2021-07-25 11:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0022_auto_20210725_1700'),
    ]

    operations = [
        migrations.AddField(
            model_name='assessment',
            name='pass_score',
            field=models.FloatField(default=10),
            preserve_default=False,
        ),
    ]
