# Generated by Django 3.2.5 on 2021-07-20 14:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0011_alter_candidatejob_step'),
    ]

    operations = [
        migrations.AlterField(
            model_name='candidatejob',
            name='step',
            field=models.JSONField(blank=True, null=True),
        ),
    ]
