# Generated by Django 3.2.5 on 2021-07-28 14:07

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0028_remove_assessment_score'),
    ]

    operations = [
        migrations.RenameField(
            model_name='assessment',
            old_name='pass_score',
            new_name='pass_percentage',
        ),
    ]
