# Generated by Django 3.2.5 on 2021-07-02 06:24

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0004_auto_20210629_1947'),
    ]

    operations = [
        migrations.AlterField(
            model_name='job',
            name='assessment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='assessment', to='job_board.assessment'),
        ),
        migrations.AlterField(
            model_name='jobsummery',
            name='job',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='job_summery', to='job_board.job'),
        ),
    ]
