# Generated by Django 3.2.5 on 2021-07-27 16:34

from django.db import migrations, models
import tinymce.models


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0025_assessment_open_to_start'),
    ]

    operations = [
        migrations.AlterField(
            model_name='assessment',
            name='score',
            field=models.FloatField(default=0, help_text='This will auto'),
        ),
        migrations.AlterField(
            model_name='assessmentanswer',
            name='title',
            field=tinymce.models.HTMLField(),
        ),
        migrations.AlterField(
            model_name='assessmentquestion',
            name='title',
            field=tinymce.models.HTMLField(),
        ),
    ]
