# Generated by Django 3.2.5 on 2021-07-24 16:50

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0015_candidateassessment'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='candidatejob',
            name='mcq_exam_score',
        ),
        migrations.RemoveField(
            model_name='candidatejob',
            name='mcq_exam_started_at',
        ),
        migrations.RemoveField(
            model_name='candidatejob',
            name='step',
        ),
        migrations.RemoveField(
            model_name='candidatejob',
            name='viva_exam_score',
        ),
        migrations.RemoveField(
            model_name='candidatejob',
            name='written_exam_score',
        ),
        migrations.AlterField(
            model_name='candidateassessment',
            name='assessment',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='job_board.assessment'),
        ),
    ]
