# Generated by Django 3.2.5 on 2021-07-20 19:04

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0012_alter_candidatejob_step'),
    ]

    operations = [
        migrations.CreateModel(
            name='CandidateAssessmentAnswer',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('total_score', models.FloatField()),
                ('answers', models.JSONField()),
                ('score_achieve', models.FloatField()),
                ('question', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='job_board.assessmentquestion')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
