# Generated by Django 3.2.5 on 2021-07-19 10:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0007_auto_20210714_1637'),
    ]

    operations = [
        migrations.CreateModel(
            name='ResetPassword',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('email', models.EmailField(max_length=254)),
                ('otp', models.CharField(max_length=10)),
                ('otp_expire_at', models.DateTimeField()),
                ('otp_used_at', models.DateTimeField(blank=True, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
