# Generated by Django 3.2.5 on 2021-07-20 08:28

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django_userforeignkey.models.fields


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('job_board', '0008_resetpassword'),
    ]

    operations = [
        migrations.CreateModel(
            name='JobAdditionalField',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('title', models.CharField(max_length=255)),
                ('required', models.BooleanField(default=True)),
                ('validation_regx', models.CharField(blank=True, max_length=255, null=True)),
                ('created_by', django_userforeignkey.models.fields.UserForeignKey(blank=True, editable=False, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='job_board_jobadditionalfield_related', to=settings.AUTH_USER_MODEL, verbose_name='Created By')),
                ('job', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='additional_fields', to='job_board.job')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
