{% extends 'admin/change_form.html' %}

{% block after_related_objects %}

    {% if object_id %}
        <h1>Job Application History</h1>
        <table width="100%">
            <thead>
            <tr>
                <th>#</th>
                <th>Job</th>
                <th>Applied At</th>
                <th>Assessment At</th>
                <th>MCQ Score</th>
                <th>Written Score</th>
                <th>Viva Score</th>
            </tr>
            </thead>
            <tbody>
            {% for candidate_job in candidate_jobs %}
                <tr>
                    <td>{{ forloop.counter }}</td>
                    <td>{{ candidate_job.job }}</td>
                    <td>{{ candidate_job.created_at }}</td>
                    <td></td>
                    <td>{{ candidate_job.mcq_exam_score }}</td>
                    <td>{{ candidate_job.written_exam_score }}</td>
                    <td>{{ candidate_job.viva_exam_score }}</td>
                </tr>
            {% endfor %}
            </tbody>
        </table>
        <br>
    {% endif %}
{% endblock %}