# Generated by Django 3.2.5 on 2021-07-25 10:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0019_auto_20210725_1648'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='candidateassessment',
            name='exam_type',
        ),
    ]
