# Generated by Django 3.2.4 on 2021-06-29 13:47

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0003_alter_job_assessment'),
    ]

    operations = [
        migrations.AddField(
            model_name='candidatejob',
            name='unique_id',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AlterField(
            model_name='assessmentanswer',
            name='assessment_question',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='answers', to='job_board.assessmentquestion'),
        ),
        migrations.AlterField(
            model_name='job',
            name='assessment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='job_board.assessment'),
        ),
    ]
