# Generated by Django 3.2.5 on 2021-07-24 16:31

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0014_candidateassessmentanswer_candidate_job'),
    ]

    operations = [
        migrations.CreateModel(
            name='CandidateAssessment',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('unique_id', models.UUIDField(default=uuid.uuid4, editable=False)),
                ('exam_started_at', models.DateTimeField(blank=True, null=True)),
                ('exam_end_at', models.DateTimeField(blank=True, null=True)),
                ('score', models.FloatField(default=0)),
                ('step', models.JSONField(blank=True, null=True)),
                ('exam_type', models.CharField(choices=[('mcq', 'MCQ Assessment'), ('written', 'Written Assessment'), ('viva', 'Viva Assessment')], max_length=50)),
                ('assessment', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='job_board.assessment')),
                ('candidate_job', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='job_board.candidatejob')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
